### Make calculations for figures that show summary /
### main results of simulations; is slow; writes RData files
##---------------------------------------------------------

## ---------------------------------------------------
## identical to 'makesummary.R', but different setting
## ---------------------------------------------------

## USAGE:
## within R: source("./scripts/makesummary2.R")
## shell: R CMD BATCH ./scripts/makesummary2.R &
## change settings for '## <<<' lines
## --------------------------------------------------------

nrep<-20 ## <<< number of replicates as in simulations
outgen<-seq(10,100,10) ## <<< output generations as in simulations (or subset)
ndeme<-3  ## <<< number of demes as in simulations
nloci<-510 ## <<< number of markers as in simulations

REDUCED<-500 ## <<< reduce output for >= 500 individuals per deme

## <<< read in the runs
runnames<-c("deme500_1/path_m0.01_neutral","deme500_1/path_m0.01_c0.2",
            "deme500_1/path_m0.01_c0.9","deme500_1/path_m0.2_neutral",
            "deme500_1/path_m0.2_c0.2","deme500_1/path_m0.2_c0.9")

## --------------------------------------------------------


##-----------------
calcLD<-function(haplovec1, haplovec2){ ## vectors with haplotypes (0 or 1) of locus 1 and 2
    ## haplotype counts
    C00<-sum(haplovec1==0 & haplovec2==0, na.rm=T)
    C11<-sum(haplovec1==1 & haplovec2==1, na.rm=T)
    C01<-sum(haplovec1==0 & haplovec2==1, na.rm=T)
    C10<-sum(haplovec1==1 & haplovec2==0, na.rm=T)
    ## haplotype freqs
    P00<-C00/(C00+C11+C01+C10)
    P11<-C11/(C00+C11+C01+C10)
    P01<-C01/(C00+C11+C01+C10)
    P10<-C10/(C00+C11+C01+C10)
    ## LD
    Dtmp<- P00*P11 - P01*P10
    ## allele freqs
    ploc1<-sum(haplovec1==0,na.rm=T)/sum(haplovec1==0 | haplovec1==1,na.rm=T)
    ploc2<-sum(haplovec2==0,na.rm=T)/sum(haplovec2==0 | haplovec2==1,na.rm=T)

    Dmin<-max(-1 * ploc1*ploc2, -1 * (1-ploc1)*(1-ploc2))
    Dmax<-min(ploc1*(1-ploc2), (1-ploc1)*ploc2)
    ## D
    D<- Dtmp
    ## D prime
    Dprime<-ifelse(Dtmp<0,Dtmp/Dmin,ifelse(Dtmp>0,Dtmp/Dmax,0))
    ## r square
    rsquare<-(Dtmp^2)/(ploc1*(1-ploc1)*ploc2*(1-ploc2)) ## sqrt(rsquare) is corr coeff

    return(list(D=D,Dprime=Dprime,rsquare=rsquare))
}
##-----------------





## calculate Fst, q, het, LD ##
## ----------------------------
for (myname in runnames){

    ## read main file for current run
    main<-read.table(paste(myname,".main",sep=""),sep=",",header=T)

    ##----
    subset<-numeric(0)

    for(r in 1:nrep){
        for(g in 1:length(outgen)){
            for(d in 1:ndeme){
                tmp<-which(main$rep==r & main$gen==outgen[g] &
                               main$deme==d & !is.na(main$l1.1) )
                ifelse(length(tmp)>REDUCED,subset<-c(subset,sample(tmp,REDUCED)),subset<-c(subset,tmp))
            }
        }
    }

    subset<-sort(subset)
    haplosubset<-sort(c(2*subset-1,2*subset))

    main<-main[subset,]
    ##----

    rFst<-array(dim=c(nloci,length(outgen),nrep))
    ## locus-specific ancestry
    rlsq<-array(dim=c(nloci,ndeme,length(outgen),nrep))
    ## locus-specific heterozygosity
    rlshet<-array(dim=c(nloci,ndeme,length(outgen),nrep))


    for(r in 1:nrep){

        for(g in 1:length(outgen)){

            afdeme<-array(dim=c(nloci,ndeme))
            Hodeme<-array(dim=c(nloci,ndeme))

            for(d in 1:ndeme){
                afdeme[,d]<-apply(main[main$rep==r & main$gen==outgen[g] &
                                           main$deme==d,-(1:8)],2,
                                  function(x) mean(x,na.rm=T))/2 ## allele freq
                Hodeme[,d]<-apply((main[main$rep==r & main$gen==outgen[g] &
                                            main$deme==d,-(1:8)]==1),2,
                                  function(x) mean(x,na.rm=T)) ## observed het
            }
            ## expected het
            Hedeme<-2*afdeme*(1-afdeme)
            afall<-apply(main[main$rep==r & main$gen==outgen[g],-(1:8)],2,
                         function(x) mean(x,na.rm=T))/2

            ## expected het (metapop)
            Ht<-2*afall*(1-afall)
            Hs<-apply(Hedeme,1,function(x) mean(x,na.rm=T))

            rFst[,g,r]<-(Ht - Hs)/Ht
            rlsq[,,g,r]<-afdeme
            rlshet[,,g,r]<-Hodeme
        }

    }

    repFst<-apply(rFst,c(1,2),function(x) mean(x,na.rm=T))
    replsq<-apply(rlsq,c(1,2,3),function(x) mean(x,na.rm=T))
    replshet<-apply(rlshet,c(1,2,3),function(x) mean(x,na.rm=T))


    save(rFst,rlsq,rlshet,repFst,replsq,replshet,
         file=paste(myname,"_FstQHet",".RData",sep=""))

    rm(main,rFst,rlsq,rlshet,repFst,replsq,replshet)

    ## read haplo file for current run
    haplo<-read.table(paste(myname,"copy.haplo",sep=""),sep=",",header=T)

    ##---
    haplo<-haplo[haplosubset,]
    ##---

    rDprime.5<-array(dim=c(nloci-5,ndeme,length(outgen),nrep))
    rrsquare.5<-array(dim=c(nloci-5,ndeme,length(outgen),nrep))

    for(r in 1:nrep){
        for(d in 1:ndeme){
            for(g in 1:length(outgen)){
                sub<-haplo[haplo$rep==r & haplo$gen==outgen[g] & haplo$deme==d, -(1:8)]

                for(m in 1:(nloci-5)){
                    tmp5<-calcLD(sub[,m],sub[,m+5])
                    rDprime.5[m,d,g,r]<-tmp5$Dprime
                    rrsquare.5[m,d,g,r]<-tmp5$rsquare
                }
            }
        }
    }


    repDprime.5<-apply(rDprime.5,c(1,2,3),function(x) mean(x,na.rm=T))
    reprsquare.5<-apply(rrsquare.5,c(1,2,3),function(x) mean(x,na.rm=T))


    save(rDprime.5,rrsquare.5,repDprime.5,reprsquare.5,
         file=paste(myname,"_LD",".RData",sep=""))

    rm(haplo,rDprime.5,rrsquare.5,repDprime.5,reprsquare.5)

}



