#!/usr/bin/perl -w


## output is written relative to the current wd from where this perl script is called
## ----------------------------------------------------------------------------------
## USAGE: ./scripts/run_dfuse.pl &> logfile.txt &
## change settings for '## <<<' lines
## ----------------------------------------------------------------------------------

##$mydfuse = 'path/to/dfuse'; ## <<< specify path to program
$mydfuse = './dfuse_src/dfuse';
##$myinputfilesfolder = 'path/to/folder/'; ## <<< specify path to directory with input files
$myinputfilesfolder = './inputfiles/';

## possible options in dfuse:

##  -d  deme settings input file
##  -e  epistatic selection input file
##  -s  single-locus selection input file
##  -v  environment settings input file
##  -o  output file [default = "testing"]
##  -r  number of replicates [default = 1]
##  -g  number of generations [default = 10]
##  -G  print every x generations [default = 10]
##  -O  print stats for selected loci every generation [default = 0]
##  -m  migration rate [default = 0.05]
##  -c  selection coefficient [default = 0.0]
##  -a  selection against ancestral alleles on DMI ridge [default = 0.0]
##  -R  recessivity for DMIs 0=dominant, 1=co-dominant,
##                   2=partially recessive, 3=fully recessive [default = 0]
##  -S  selection stage "viability", "fertility", "both" or "none" [default = "viability"]
##  -M  migration stage "pollen", "progeny" or "both" [default = "progeny"]
##  -D  dispersal mode 0="infinite source" or 1="finite source" [default = "infinite source"]
##  -l  marker loci per chromosome [default = 51]
##  -Y  generation to start "staining" [default = 0 (no "staining")]

## ------------------------------------------------ ##
## INPUT ##
## ------------------------------------------------ ##
## specify 'undefined' for defaults (no input files)
$opt_d = $myinputfilesfolder.'demefile_2'; ## <<< deme settings
$opt_e = $myinputfilesfolder.'epifile_1'; ## <<< epistatic loci
##$opt_s = $myinputfilesfolder.'selfile_1'; ## <<< other selected loci, or
$opt_s = 'undefined'; ## <<< other selected loci
##$opt_v = $myinputfilesfolder.'envifile_1'; ## <<< environmental settings, or
$opt_v = 'undefined'; ## <<< environmental settings

$nofile = 'undefined';

$opt_s_neutral = $opt_s; ## <<< if single-locus selection file also includes
##  selection other than environmental selection (i.e., overdominance),
##  a second version for file in $opt_s would be needed that excludes such loci
##  to generate "neutral" simulation runs (i.e., environmental selection only)

## ------------------------------------------------ ##
## OUTPUT ##
## ------------------------------------------------ ##
$opt_o = 'dmi'; ## <<< set prefix

$mydir = 'deme500'; ## <<< name of directory for simulation output
$mknew = 1; ## make new dir if required (1) or not (0)


if ($mknew == 1){

    $count = 1;
    while (-d $mydir){
	while (-d $mydir."_".$count){
	    $count += 1;
	}
	$mydir = $mydir."_".$count;
    }
    mkdir $mydir, 0755 or warn "Cannot make '$mydir': $!";

}

if (($mknew == 0) && (-d $mydir)){
    print "\nWarning: '$mydir' exists, output might be overwritten\n";
}

unless (-d $mydir){
    die "\nCannot write output, '$mydir' does not exist\n\n";
}

## ------------------------------------------------ ##
## PARAMS ##
## ------------------------------------------------ ##

$opt_r = 20; ## <<< replicates
$opt_g = 100; ## <<< generations
$opt_G = 10; ## <<< interval for output generations
$opt_O = 0; ##
$opt_m = 0.1; ## overwritten in loop below
$opt_c = 0.1; ## overwritten in loop below
$opt_a = 0.0; ##
$opt_R = 0; ##
$opt_D = 0; ##
$opt_Y = 0; ##



## a loop with different settings for migration and selection
## ----------------------------------------------------------
$outname = $opt_o;

foreach $opt_m (0.01, 0.2){ ## <<< migration rates

    ## make neutral sims without selection

    ## make a bit different out filename
    ## (should really be called 'neutral' for R script)
    $opt_o = $outname."_m".$opt_m."_neutral";

    if ($opt_s eq 'undefined'){ ## run without any selection
	$mycommand = "$mydfuse -d $opt_d -e $nofile -s $nofile -v $nofile -o $mydir/$opt_o -r $opt_r -g $opt_g -G $opt_G -m $opt_m -c 0.0 -a 0.0 -D $opt_D -Y $opt_Y";
    }
    else { ## run with environmental selection only
	$mycommand = "$mydfuse -d $opt_d -e $nofile -s $opt_s_neutral -v $opt_v -o $mydir/$opt_o -r $opt_r -g $opt_g -G $opt_G -m $opt_m -c 0.0 -a 0.0 -D $opt_D -Y $opt_Y";
    }

    print "\n$mycommand \n\n";
    system $mycommand;

    ## replace allele states in .haplo by 0s or 1s (ready to use in C code too)
    $copy = $mydir."/".$opt_o."copy.haplo";
    system "cat $mydir/$opt_o.haplo | sed 's/,a/,1/g' | sed 's/,A/,1/g' | sed 's/,b/,0/g' | sed 's/,B/,0/g' > $copy";


    ## continue with selection
    foreach $opt_c (0.2, 0.9){ ## <<< selection strengths

	## to make a bit different out filename
	$opt_o = $outname."_m".$opt_m."_c".$opt_c;

	$mycommand = "$mydfuse -d $opt_d -e $opt_e -s $opt_s -v $opt_v -o $mydir/$opt_o -r $opt_r -g $opt_g -G $opt_G -O $opt_O -m $opt_m -c $opt_c -a $opt_a -R $opt_R -D $opt_D -Y $opt_Y";

	print "\n$mycommand \n\n";
	system $mycommand;

	## replace allele states in .haplo by 0s or 1s (ready to use in C code too)
	$copy = $mydir."/".$opt_o."copy.haplo";
	system "cat $mydir/$opt_o.haplo | sed 's/,a/,1/g' | sed 's/,A/,1/g' | sed 's/,b/,0/g' | sed 's/,B/,0/g' > $copy";

    }
}
## ----------------------------------------------------------


exit;

