### Figures that show summary / main results of simulations
##---------------------------------------------------------

## USAGE:
## within R: source("./scripts/summaryfigssetup.R")
## shell: R CMD BATCH ./scripts/summaryfigssetup.R &
## change settings for '## <<<' lines
## --------------------------------------------------------

rm(list=ls())

library(RColorBrewer)

nchr<-10 ## <<< number of chromosomes as in simulations
nrep<-20 ## <<< number of replicates as in simulations
ngen<-100 ## <<< number of generations as in simulations
outgen<-seq(10,100,10) ## <<< output generations as in simulations;
                   ## should be <=8 for brewer.pal (reduced below)
ndeme<-3  ## <<< number of demes as in simulations
nloci<-510 ## <<< number of markers as in simulations

## --------------------------------------------------------
xsteps<-seq(0,nloci,nloci/nchr)+0.5
start.chr<-seq(1,nloci,nloci/nchr)
end.chr<-seq(nloci/nchr,nloci,nloci/nchr)


#############  setup for deme500 / deme500_1 ###############
## positions selected loci
selpos1<-c(0.4,0.6) ## <<< Morgans, column 1 in plot
selchr1<-c(0,0) ## <<< chromosomes, column 1 in plot
selpos2<-c(0.4,0.6) ## <<< Morgans, column 2 in plot
selchr2<-c(0,0) ## <<< chromosomes, column 2 in plot
selpos3<-c(0.2,0.4,0.6,0.8) ## <<< Morgans, column 3 in plot
selchr3<-c(0,0,0,0) ## <<< chromosomes, column 3 in plot
selpos4<-c(0.2,0.4,0.6,0.8) ## <<< Morgans, column 4 in plot
selchr4<-c(0,0,0,0) ## <<< chromosomes, column 4 in plot


sel1<-selpos1*(nloci/nchr -1) + start.chr[selchr1+1]
sel2<-selpos2*(nloci/nchr -1) + start.chr[selchr2+1]
sel3<-selpos3*(nloci/nchr -1) + start.chr[selchr3+1]
sel4<-selpos4*(nloci/nchr -1) + start.chr[selchr4+1]


nsets=4

## <<< the runs to be plotted
runnames<-c("deme500/dmi_m0.01_neutral","deme500/dmi_m0.01_c0.2",
            "deme500/dmi_m0.01_c0.9","deme500/dmi_m0.2_neutral",
            "deme500/dmi_m0.2_c0.2","deme500/dmi_m0.2_c0.9",
            "deme500_1/path_m0.01_neutral","deme500_1/path_m0.01_c0.2",
            "deme500_1/path_m0.01_c0.9","deme500_1/path_m0.2_neutral",
            "deme500_1/path_m0.2_c0.2","deme500_1/path_m0.2_c0.9")

## <<< selection coefficients of runs
legendnames<-c("s=0.0","s=0.2","s=0.9",
               "s=0.0","s=0.2","s=0.9",
               "s=0.0","s=0.2","s=0.9",
               "s=0.0","s=0.2","s=0.9")


## <<< header for plot
myrunhead<-c("DMIs, m=0.01","DMIs, m=0.2","Pathways, m=0.01","Pathways, m=0.2")
mysubheads<-c("s=0.2","s=0.9","s=0.9, single replicate")

bc.heads<-paste(rep(myrunhead,each=2),rep(mysubheads[c(1,2)],times=2),sep=", ")


## <<< which full files to load, in right order for plot
loadingnames<-c("deme500/dmi_m0.01_c0.2","deme500/dmi_m0.01_c0.9",
                "deme500/dmi_m0.2_c0.2","deme500/dmi_m0.2_c0.9",
                "deme500_1/path_m0.01_c0.2","deme500_1/path_m0.01_c0.9",
                "deme500_1/path_m0.2_c0.2","deme500_1/path_m0.2_c0.9")

## <<< legend positions might need to be adjusted
legendposition<-"topright" ## for Fst plots
summarylegendpos<-"topright" ## for summary Fst plots (sel coeff)
summarylegendpos2<-"top" ## for summary Fst plots (mean-sd)
legendposition2<-c("topright","topright","bottomright") ## for second plot
legendposition3<-c("topright","topright","bottomright") ## for third plot

###########################################################################

## read summary stats files
##-------------------------
mystatfiles<-runnames ##[1:6]
i<-1
tmp<-read.csv(paste(mystatfiles[i],".stats",sep="")) ## C stats output

mystats<-array(dim=c(dim(tmp),length(mystatfiles)),dimnames=list(NULL,colnames(tmp),mystatfiles))
mystats[,,i]<-as.matrix(tmp)

for(i in 2:length(mystatfiles)){
    tmp<-read.csv(paste(mystatfiles[i],".stats",sep=""))
    mystats[,,i]<-as.matrix(tmp)
}

rm(tmp)


## loads rFst,rlsq,rlshet,repFst,replsq,replshet; rename after loading
load(paste(loadingnames[1],"_FstQHet",".RData",sep=""))
dat1_rFst<-rFst
dat1_rlsq<-rlsq
dat1_rlshet<-rlshet
dat1_repFst<-repFst
dat1_replsq<-replsq
dat1_replshet<-replshet
rm(rFst,rlsq,rlshet,repFst,replsq,replshet)

load(paste(loadingnames[2],"_FstQHet",".RData",sep=""))
dat2_rFst<-rFst
dat2_rlsq<-rlsq
dat2_rlshet<-rlshet
dat2_repFst<-repFst
dat2_replsq<-replsq
dat2_replshet<-replshet
rm(rFst,rlsq,rlshet,repFst,replsq,replshet)

load(paste(loadingnames[3],"_FstQHet",".RData",sep=""))
dat3_rFst<-rFst
dat3_rlsq<-rlsq
dat3_rlshet<-rlshet
dat3_repFst<-repFst
dat3_replsq<-replsq
dat3_replshet<-replshet
rm(rFst,rlsq,rlshet,repFst,replsq,replshet)

load(paste(loadingnames[4],"_FstQHet",".RData",sep=""))
dat4_rFst<-rFst
dat4_rlsq<-rlsq
dat4_rlshet<-rlshet
dat4_repFst<-repFst
dat4_replsq<-replsq
dat4_replshet<-replshet
rm(rFst,rlsq,rlshet,repFst,replsq,replshet)


load(paste(loadingnames[5],"_FstQHet",".RData",sep=""))
dat5_rFst<-rFst
dat5_rlsq<-rlsq
dat5_rlshet<-rlshet
dat5_repFst<-repFst
dat5_replsq<-replsq
dat5_replshet<-replshet
rm(rFst,rlsq,rlshet,repFst,replsq,replshet)

load(paste(loadingnames[6],"_FstQHet",".RData",sep=""))
dat6_rFst<-rFst
dat6_rlsq<-rlsq
dat6_rlshet<-rlshet
dat6_repFst<-repFst
dat6_replsq<-replsq
dat6_replshet<-replshet
rm(rFst,rlsq,rlshet,repFst,replsq,replshet)

load(paste(loadingnames[7],"_FstQHet",".RData",sep=""))
dat7_rFst<-rFst
dat7_rlsq<-rlsq
dat7_rlshet<-rlshet
dat7_repFst<-repFst
dat7_replsq<-replsq
dat7_replshet<-replshet
rm(rFst,rlsq,rlshet,repFst,replsq,replshet)

load(paste(loadingnames[8],"_FstQHet",".RData",sep=""))
dat8_rFst<-rFst
dat8_rlsq<-rlsq
dat8_rlshet<-rlshet
dat8_repFst<-repFst
dat8_replsq<-replsq
dat8_replshet<-replshet
rm(rFst,rlsq,rlshet,repFst,replsq,replshet)


## load LD (rDprime.5, rrsquare.5, repDprime.5, reprsquare.5); rename after loading
load(paste(loadingnames[1],"_LD",".RData",sep=""))
dat1_repDprime.5<-repDprime.5
rm(rDprime.5, rrsquare.5, repDprime.5, reprsquare.5)

load(paste(loadingnames[2],"_LD",".RData",sep=""))
dat2_repDprime.5<-repDprime.5
rm(rDprime.5, rrsquare.5, repDprime.5, reprsquare.5)

load(paste(loadingnames[3],"_LD",".RData",sep=""))
dat3_repDprime.5<-repDprime.5
rm(rDprime.5, rrsquare.5, repDprime.5, reprsquare.5)

load(paste(loadingnames[4],"_LD",".RData",sep=""))
dat4_repDprime.5<-repDprime.5
rm(rDprime.5, rrsquare.5, repDprime.5, reprsquare.5)


load(paste(loadingnames[5],"_LD",".RData",sep=""))
dat5_repDprime.5<-repDprime.5
rm(rDprime.5, rrsquare.5, repDprime.5, reprsquare.5)

load(paste(loadingnames[6],"_LD",".RData",sep=""))
dat6_repDprime.5<-repDprime.5
rm(rDprime.5, rrsquare.5, repDprime.5, reprsquare.5)

load(paste(loadingnames[7],"_LD",".RData",sep=""))
dat7_repDprime.5<-repDprime.5
rm(rDprime.5, rrsquare.5, repDprime.5, reprsquare.5)

load(paste(loadingnames[8],"_LD",".RData",sep=""))
dat8_repDprime.5<-repDprime.5
rm(rDprime.5, rrsquare.5, repDprime.5, reprsquare.5)




##------------------------------------------------------
plotgen<-c(1,2,4,6,8) ## subset output generations to be plotted;
                      ## should be <=8 for brewer.pal

runcols<-rep(c("black",brewer.pal(n=8,name="Dark2")[1:2]),times=nsets)

## Fst (blues)
my.pal<-brewer.pal(8+1,"Blues")[-1] # up to 8 colors (don't use first)
my.lwd<-rev(seq(1,8,1)/2)

## ancestry
my.oranges<-brewer.pal(8+1,"Oranges")[-1] # up to 8 colors (don't use first)
## heterozygosity
my.greens<-brewer.pal(8+1,"Greens")[-1] # up to 8 colors (don't use first)
## LD
my.reds<-brewer.pal(8+1,"Reds")[-1] ## up to 8 colors (don't use first)

my.pal<-my.pal[plotgen]
my.lwd<-my.lwd[plotgen]
my.oranges<-my.oranges[plotgen]
my.greens<-my.greens[plotgen]
my.reds<-my.reds[plotgen]

lastmarker<-225 ## last marker for plot to truncate x-axis

mydeme<-2 ## <<< hybrid deme (deme to plot in plots 2 and 3)


##-----------
## PLOT
##-----------
## (this plots data from all 500 inds per deme)

## plot 1: Fst
pdf("Figure2.pdf",width=6*(nsets/2))
source("./scripts/summaryfigsplot.R")
dev.off()


## plot 2: q, het and D' for files 2,4,6,8
pdf("Figure3.pdf",width=6*(nsets/2),height=4.5)
source("./scripts/summaryfigsplot2.R")
dev.off()


## plots q, het and D' for files 1,3,5,7
pdf("Figure4.pdf",width=6*(nsets/2),height=4.5)
source("./scripts/summaryfigsplot3.R")
dev.off()

##-----------

